@@ -17,12 +17,16 @@
 #' - Decay functions. Run `vignette("decay_functions", package =
 #' "accessibility")` or check it on the [website](
 #' https://ipeagit.github.io/accessibility/articles/decay_functions.html).
+#' - Calculating accessibility inequality and poverty. Run
+#' `vignette("inequality_and_poverty", package = "accessibility")` or check it
+#' on the
+#' [website](https://ipeagit.github.io/accessibility/articles/inequality_and_poverty.html).
 #'
 #' @docType package
 #' @name accessibility
 #' @aliases accessibility-package
 #'
-#' @importFrom data.table := .I .SD %chin% .GRP .N fifelse
+#' @importFrom data.table := .I .SD %chin% .GRP .N
 #' @importFrom utils globalVariables
 #' @importFrom Rdpack reprompt
 #'
@@ -72,7 +76,31 @@ utils::globalVariables(
     ".fgt0",
     ".fgt1",
     ".fgt2",
-    ".norm_opp_shortfall"
+    ".norm_opp_shortfall",
+    "pop_share",
+    "upper",
+    "lower",
+    "cont_to_total",
+    "correction_factor",
+    "diff_from_avg",
+    "fractional_rank",
+    "..population",
+    "access_share",
+    "component",
+    "group_avg_access",
+    "group_theil_t",
+    "theil_share",
+    "total_access",
+    "group_total_access",
+    "contribution",
+    "value",
+    "within_ineq",
+    "between_share",
+    "group_tot_access",
+    "share_of_component",
+    "group_tot_pop",
+    "total",
+    "share_of_total"
   )
 )
 
